@@ -221,36 +221,44 @@ def datetime_to_long(dt: datetime) -> int:
 
     return (date_int << 32) + time_int
 
+
 tenth = Decimal("0.1")
 if getcontext().prec < 38:
     getcontext().prec = 38
-def sq_numeric_to_decimal(bigint: int, scale: int) -> Decimal:
-    if getcontext().prec < 38:
-        getcontext().prec = 38
+
+def sq_numeric_to_decimal(bigint_as_bytes: bytes, scale: int) -> Decimal:
+    
+    getcontext().prec = 38
+    c = memoryview(bigint_as_bytes).cast('i')
+    bigint = ((c[3] << 96) + ((c[2] & 0xffffffff) << 64) + ((c[1] & 0xffffffff) << 32) + (c[0] & 0xffffffff))
+
     return Decimal(bigint) * (tenth ** scale)
 
+
 def decimal_to_sq_numeric(dec: Decimal, scale: int) -> int: # returns bigint
     if getcontext().prec < 38:
         getcontext().prec = 38
     res = dec * (10 ** scale)
     return ceil(res) if res > 0 else floor(res)
 
-def bytes_to_bigint(bytes) -> int:
-    c = unpack('4i', bytes)
-    res = ((c[3] << 96) + ((c[2] & 0xffffffff) << 64) + ((c[1] & 0xffffffff) << 32) + (c[0] & 0xffffffff))
-    return res
 
 try:
     from cythonized import date_to_int as pydate_to_int, datetime_to_long as pydt_to_long, sq_date_to_py_date as date_to_py, sq_datetime_to_py_datetime as dt_to_py
+    logger.debug("Using cython")
+    CYTHON = True
 except:
     if CYTHON:
         try:
-            import pyximport; pyximport.install(pyimport=True, language_level=3, inplace=True)
+            import pyximport; py_importer, pyx_importer = pyximport.install(pyimport=True, language_level=3, inplace=True)
             from cythonized import date_to_int as pydate_to_int, datetime_to_long as pydt_to_long, sq_date_to_py_date as date_to_py, sq_datetime_to_py_datetime as dt_to_py
+            logger.debug("Using cython with pyximport")
         except:
-            CYTHON = False
-else:
-    CYTHON = True
+            try:
+                CYTHON = False
+                pyximport.uninstall(py_importer, pyx_importer)
+                logger.debug("Cython is not installed")
+            except:
+                logger.debug("Cython is not installed and can't uninstall pyximport")
 
 
 def lengths_to_pairs(nvarc_lengths):
